# Generated by Django 2.2 on 2019-09-26 13:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mds', '0051_fill_compliance_lag'),
    ]

    operations = [
        migrations.AlterField(
            model_name='compliance',
            name='lag',
            field=models.DurationField(),
        ),
    ]



# Generated by Django 2.1.5 on 2019-09-25 10:11

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('mds', '0048_add_compliance_lag'),
    ]

    operations = [
        migrations.AddField(
            model_name='policy',
            name='config',
            field=django.contrib.postgres.fields.jsonb.JSONField(default=dict),
        ),
    ]



# Generated by Django 2.2 on 2019-09-26 12:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("mds", "0047_add_daily_penalty_20190924_0933")]

    operations = [
        migrations.AddField(
            model_name="compliance",
            name="lag",
            field=models.DurationField(blank=True, null=True),
        ),
        migrations.AlterUniqueTogether(
            name="compliance",
            unique_together={
                ("policy", "rule", "geography", "vehicle", "start_date", "lag")
            },
        ),
        # Not related but forgot about that
        migrations.AlterField(
            model_name="compliance", name="geography", field=models.UUIDField()
        ),
        migrations.AlterField(
            model_name="compliance", name="rule", field=models.UUIDField()
        ),
    ]



# Generated by Django 2.2 on 2019-07-03 09:36

from django.contrib.postgres.functions import TransactionNow
from django.db import migrations


def migrate_to_policy_config(apps, schema_editor):
    Policy = apps.get_model("mds", "Policy")

    for policy in Policy.objects.all():
        policy.config = {
            "fixed_price": policy.fixed_price,
            "daily_penalty": policy.daily_penalty,
            "grace_period_days": 0,
            "rule_type": "count",
        }
        policy.save()


class Migration(migrations.Migration):
    dependencies = [("mds", "0049_pre_add_policy_config")]

    operations = [migrations.RunPython(migrate_to_policy_config, migrations.RunPython.noop)]



# Generated by Django 2.2.5 on 2019-09-24 09:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mds', '0046_compliance_uniqueness'),
    ]

    operations = [
        migrations.AddField(
            model_name='policy',
            name='daily_penalty',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='compliance',
            name='geography',
            field=models.UUIDField(),
        ),
        migrations.AlterField(
            model_name='compliance',
            name='rule',
            field=models.UUIDField(),
        ),
    ]



# Generated by Django 2.2 on 2019-09-26 13:05
import datetime

from django.db import migrations


def fill_compliance_lag(apps, schema_editor):
    Compliance = apps.get_model("mds", "Compliance")
    # The default value on compliances already computed
    Compliance.objects.update(lag=datetime.timedelta(0))


class Migration(migrations.Migration):

    dependencies = [("mds", "0050_pre_migrate_to_policy_config")]

    operations = [migrations.RunPython(fill_compliance_lag, migrations.RunPython.noop)]



# Generated by Django 2.1.5 on 2019-09-25 10:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('mds', '0052_required_compliance_lag'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='policy',
            name='daily_penalty',
        ),
        migrations.RemoveField(
            model_name='policy',
            name='fixed_price',
        ),
    ]
